==> oakvar-2.11.9.tar.gz: oakvar-2.11.9/oakvar/lib/base/app.py <==
# OakVar
# 
# Copyright (c) 2024 Oak Bioinformatics, LLC
# 
# All rights reserved.
# 
# Do not distribute or use this software without obtaining 
# a license from Oak Bioinformatics, LLC.
# 
# Do not use this software to develop another software 
# which competes with the products by Oak Bioinformatics, LLC, 
# without obtaining a license for such use from Oak Bioinformatics, LLC.
# 
# For personal use of non-commercial nature, you may use this software
# after registering with `ov store account create`.
# 
# For research use of non-commercial nature, you may use this software
# after registering with `ov store account create`.
# 
# For use by commercial entities, you must obtain a commercial license
# from Oak Bioinformatics, LLC. Please write to info@oakbioinformatics.com
# to obtain the commercial license.
# ================
# OpenCRAVAT
# 
# MIT License
# 
# Copyright (c) 2021 KarchinLab
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from typing import Dict
from typing import Any

class BaseApp:
    def __init__(self, *args, module_name: str="", **kwargs):
        import sys
        from pathlib import Path
        from ..exceptions import ModuleLoadingError
        from ..module.local import get_module_conf

        _ = args
        _ = kwargs
        if module_name:
            self.module_name = module_name
        else:
            main_fpath = Path(sys.modules[self.__class__.__module__].__file__ or "")
            self.module_name = main_fpath.stem
        if not self.module_name:
            raise ModuleLoadingError(msg=f"App ({self.__class__.__name__}) could not be loaded.")
        self.conf: Dict[str, Any] = get_module_conf(self.module_name, module_type="app") or {}

==> oakvar-2.11.18.tar.gz: oakvar-2.11.18/oakvar/lib/base/app.py <==
# OakVar
#
# Copyright (c) 2024 Oak Bioinformatics, LLC
#
# All rights reserved.
#
# Do not distribute or use this software without obtaining
# a license from Oak Bioinformatics, LLC.
#
# Do not use this software to develop another software
# which competes with the products by Oak Bioinformatics, LLC,
# without obtaining a license for such use from Oak Bioinformatics, LLC.
#
# For personal use of non-commercial nature, you may use this software
# after registering with `ov store account create`.
#
# For research use of non-commercial nature, you may use this software
# after registering with `ov store account create`.
#
# For use by commercial entities, you must obtain a commercial license
# from Oak Bioinformatics, LLC. Please write to info@oakbioinformatics.com
# to obtain the commercial license.
# ================
# OpenCRAVAT
#
# MIT License
#
# Copyright (c) 2021 KarchinLab
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of
# this software and associated documentation files (the "Software"), to deal in
# the Software without restriction, including without limitation the rights to
# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
# of the Software, and to permit persons to whom the Software is furnished to do
# so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from typing import Dict
from typing import Any


class BaseApp:
    def __init__(self, *args, module_name: str = "", **kwargs):
        import sys
        from pathlib import Path
        from ..exceptions import ModuleLoadingError
        from ..module.local import get_module_conf

        _ = args
        _ = kwargs
        if module_name:
            self.module_name = module_name
        else:
            main_fpath = Path(sys.modules[self.__class__.__module__].__file__ or "")
            self.module_name = main_fpath.stem
        if not self.module_name:
            raise ModuleLoadingError(
                msg=f"App ({self.__class__.__name__}) could not be loaded."
            )
        self.conf: Dict[str, Any] = (
            get_module_conf(self.module_name, module_type="app") or {}
        )
